==> libstpk-0.9.0.1.tar.gz: libstpk-0.9.0.1/src/max_min.f90 <==
module max_min  ! ׻⥸塼 1
contains


!-- 1 Ѻ, ֹ롼
subroutine max_val_1d(var, mamn, mamv, undef)  ! 1 Ѻ, ֹ롼
  implicit none
  real, intent(in) :: var(:)  ! õ
  integer, intent(inout) :: mamn  ! κͤ˳ֹ
  real, intent(inout) :: mamv  ! κ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  ! Ŀ(size ؿǼư׻)
  integer :: i  ! 졼ź

  nx=size(var)

  mamv=var(1)
  mamn=1

  if(present(undef))then
     do i=2,nx
        if(var(i)>mamv.and.var(i)/=undef)then
           mamv=var(i)
           mamn=i
        end if
     end do
  else
     do i=2,nx
        if(var(i)>mamv)then
           mamv=var(i)
           mamn=i
        end if
     end do
  end if

end subroutine max_val_1d


!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
subroutine max_val_2d(var, mamnx, mamny, mamv, undef)  ! 2 Ѻ, ֹ롼
  implicit none
  real, intent(in) :: var(:,:)  ! 2 õ
  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
  real, intent(inout) :: mamv  ! κ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
  integer :: j  ! 졼ź
  real :: tmp(size(var,2))  ! 
  integer :: tmp_num(size(var,2))  ! 

  nx=size(var,1)
  ny=size(var,2)

  if(present(undef))then
     do j=1,ny
        call max_val_1d(var(:,j),tmp_num(j),tmp(j),undef)
     end do
     call max_val_1d(tmp,mamny,mamv,undef)
  else
     do j=1,ny
        call max_val_1d(var(:,j),tmp_num(j),tmp(j))
     end do
     call max_val_1d(tmp,mamny,mamv)
  end if

  mamnx=tmp_num(mamny)

end subroutine max_val_2d


!-- Ʊͤιͤ, 3  ---
subroutine max_val_3d(var, mamnx, mamny, mamnz, mamv, undef)  ! 3 Ѻ, ֹ롼
  implicit none
  real, intent(in) :: var(:,:,:)  ! 3 õ
  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
  integer, intent(inout) :: mamnz  ! κͤ˳ 3 ֹ
  real, intent(inout) :: mamv  ! κ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
  integer :: j  ! 졼ź
  real :: tmp(size(var,3))  ! 
  integer :: tmp_num1(size(var,3))  ! 
  integer :: tmp_num2(size(var,3))  ! 

  nx=size(var,1)
  ny=size(var,2)
  nz=size(var,3)

  if(present(undef))then
     do j=1,nz
        call max_val_2d(var(:,:,j),tmp_num1(j),tmp_num2(j),tmp(j),undef)
     end do
     call max_val_1d(tmp,mamnz,mamv,undef)
  else
     do j=1,nz
        call max_val_2d(var(:,:,j),tmp_num1(j),tmp_num2(j),tmp(j))
     end do
     call max_val_1d(tmp,mamnz,mamv)
  end if

  mamnx=tmp_num1(mamnz)
  mamny=tmp_num2(mamnz)

end subroutine max_val_3d



!-- 1 ѺǾ, ֹ롼
subroutine min_val_1d(var, mimn, mimv, undef)
  implicit none
  real, intent(in) :: var(:)  ! Ǿõ
  integer, intent(inout) :: mimn  ! κǾͤ˳ֹ
  real, intent(inout) :: mimv  ! κǾ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  ! Ŀ(size ؿǼư׻)
  integer :: i  ! 졼ź

  nx=size(var)

  mimv=var(1)
  mimn=1

  if(present(undef))then
     do i=2,nx
        if(var(i)<mimv.and.var(i)/=undef)then
           mimv=var(i)
           mimn=i
        end if
     end do
  else
     do i=2,nx
        if(var(i)<mimv)then
           mimv=var(i)
           mimn=i
        end if
     end do
  end if


end subroutine min_val_1d



!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
subroutine min_val_2d(var, mimnx, mimny, mimv, undef)  ! 2 ѺǾ, ֹ롼
  implicit none
  real, intent(in) :: var(:,:)  ! 2 Ǿõ
  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
  real, intent(inout) :: mimv  ! κǾ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
  integer :: j  ! 졼ź
  real :: tmp(size(var,2))  ! 
  integer :: tmp_num(size(var,2))  ! 

  nx=size(var,1)
  ny=size(var,2)

  if(present(undef))then
     do j=1,ny
        call min_val_1d(var(:,j),tmp_num(j),tmp(j),undef)
     end do
     call min_val_1d(tmp,mimny,mimv,undef)
  else
     do j=1,ny
        call min_val_1d(var(:,j),tmp_num(j),tmp(j))
     end do
     call min_val_1d(tmp,mimny,mimv)
  end if

  mimnx=tmp_num(mimny)

end subroutine min_val_2d



!-- Ʊͤιͤ, 3  ---
subroutine min_val_3d(var, mimnx, mimny, mimnz, mimv, undef)  ! 3 ѺǾ, ֹ롼
  implicit none
  real, intent(in) :: var(:,:,:)  ! 3 Ǿõ
  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
  integer, intent(inout) :: mimnz  ! κǾͤ˳ 3 ֹ
  real, intent(inout) :: mimv  ! κǾ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
  integer :: j  ! 졼ź
  real :: tmp(size(var,3))  ! 
  integer :: tmp_num1(size(var,3))  ! 
  integer :: tmp_num2(size(var,3))  ! 

  nx=size(var,1)
  ny=size(var,2)
  nz=size(var,3)

  if(present(undef))then
     do j=1,nz
        call min_val_2d(var(:,:,j),tmp_num1(j),tmp_num2(j),tmp(j),undef)
     end do
     call min_val_1d(tmp,mimnz,mimv,undef)
  else
     do j=1,nz
        call min_val_2d(var(:,:,j),tmp_num1(j),tmp_num2(j),tmp(j))
     end do
     call min_val_1d(tmp,mimnz,mimv)
  end if

  mimnx=tmp_num1(mimnz)
  mimny=tmp_num2(mimnz)

end subroutine min_val_3d



end module max_min

==> libstpk-0.9.13.0.tar.gz: libstpk-0.9.13.0/src/max_min.f90 <==
!---------------------------------------------------------------
! Copyright (C) 2009-2015 GFD Dennou Club. All rights reserved.
!---------------------------------------------------------------

module max_min  ! ׻⥸塼 1
contains


!-- 1 Ѻ, ֹ롼
subroutine max_val_1d(var, mamn, mamv, undef)  ! 1 Ѻ, ֹ롼
  implicit none
  real, intent(in) :: var(:)  ! õ
  integer, intent(inout) :: mamn  ! κͤ˳ֹ
  real, intent(inout) :: mamv  ! κ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  ! Ŀ(size ؿǼư׻)
  integer :: i  ! 졼ź
  logical :: undeflag

  nx=size(var)
  undeflag=.true.

  if(present(undef))then

     do i=1,nx
        if(var(i)/=undef)then
           if(undeflag.eqv..true.)then
              undeflag=.false.
              mamv=var(i)
              mamn=i
           else
              if(var(i)>mamv)then
                 mamv=var(i)
                 mamn=i
              end if
           end if
        end if
     end do

     if(undeflag.eqv..true.)then
        mamn=nx+1
        mamv=undef
     end if

  else

     mamv=var(1)
     mamn=1

     do i=2,nx
        if(var(i)>mamv)then
           mamv=var(i)
           mamn=i
        end if
     end do
  end if

end subroutine max_val_1d


!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
subroutine max_val_2d(var, mamnx, mamny, mamv, undef)  ! 2 Ѻ, ֹ롼
  implicit none
  real, intent(in) :: var(:,:)  ! 2 õ
  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
  real, intent(inout) :: mamv  ! κ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
  integer :: j  ! 졼ź
  real :: tmp(size(var,2))  ! 
  integer :: tmp_num(size(var,2))  ! 

  nx=size(var,1)
  ny=size(var,2)

  if(present(undef))then
     do j=1,ny
        call max_val_1d(var(:,j),tmp_num(j),tmp(j),undef)
     end do
     call max_val_1d(tmp,mamny,mamv,undef)

     if(mamny==ny+1)then
        mamnx=nx+1
     else
        mamnx=tmp_num(mamny)
     end if

  else

     do j=1,ny
        call max_val_1d(var(:,j),tmp_num(j),tmp(j))
     end do
     call max_val_1d(tmp,mamny,mamv)

     mamnx=tmp_num(mamny)

  end if

end subroutine max_val_2d


!-- Ʊͤιͤ, 3  ---
subroutine max_val_3d(var, mamnx, mamny, mamnz, mamv, undef)  ! 3 Ѻ, ֹ롼
  implicit none
  real, intent(in) :: var(:,:,:)  ! 3 õ
  integer, intent(inout) :: mamnx  ! κͤ˳ 1 ֹ
  integer, intent(inout) :: mamny  ! κͤ˳ 2 ֹ
  integer, intent(inout) :: mamnz  ! κͤ˳ 3 ֹ
  real, intent(inout) :: mamv  ! κ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
  integer :: j  ! 졼ź
  real :: tmp(size(var,3))  ! 
  integer :: tmp_num1(size(var,3))  ! 
  integer :: tmp_num2(size(var,3))  ! 

  nx=size(var,1)
  ny=size(var,2)
  nz=size(var,3)

  if(present(undef))then
     do j=1,nz
        call max_val_2d(var(:,:,j),tmp_num1(j),tmp_num2(j),tmp(j),undef)
     end do
     call max_val_1d(tmp,mamnz,mamv,undef)

     if(mamnz==nz+1)then
        mamnx=nx+1
        mamny=ny+1
     else
        mamnx=tmp_num1(mamnz)
        mamny=tmp_num2(mamnz)
     end if

  else

     do j=1,nz
        call max_val_2d(var(:,:,j),tmp_num1(j),tmp_num2(j),tmp(j))
     end do
     call max_val_1d(tmp,mamnz,mamv)

     mamnx=tmp_num1(mamnz)
     mamny=tmp_num2(mamnz)

  end if

end subroutine max_val_3d



!-- 1 ѺǾ, ֹ롼
subroutine min_val_1d(var, mimn, mimv, undef)
  implicit none
  real, intent(in) :: var(:)  ! Ǿõ
  integer, intent(inout) :: mimn  ! κǾͤ˳ֹ
  real, intent(inout) :: mimv  ! κǾ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  ! Ŀ(size ؿǼư׻)
  integer :: i  ! 졼ź
  logical :: undeflag

  nx=size(var)
  undeflag=.true.

  if(present(undef))then

     do i=1,nx
        if(var(i)/=undef)then
           if(undeflag.eqv..true.)then
              undeflag=.false.
              mimv=var(i)
              mimn=i
           else
              if(var(i)<mimv)then
                 mimv=var(i)
                 mimn=i
              end if
           end if
        end if
     end do

     if(undeflag.eqv..true.)then
        mimn=nx+1
        mimv=undef
     end if

  else

     mimv=var(1)
     mimn=1

     do i=2,nx
        if(var(i)<mimv)then
           mimv=var(i)
           mimn=i
        end if
     end do

  end if

end subroutine min_val_1d


!-- 2 Ǥ, x  y  1 롼Ƥ, Ǥκͤ1
!-- Ǽ, Ф1롼Ѥ뤳Ȥ, ΤκͤФ
subroutine min_val_2d(var, mimnx, mimny, mimv, undef)  ! 2 ѺǾ, ֹ롼
  implicit none
  real, intent(in) :: var(:,:)  ! 2 Ǿõ
  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
  real, intent(inout) :: mimv  ! κǾ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
  integer :: j  ! 졼ź
  real :: tmp(size(var,2))  ! 
  integer :: tmp_num(size(var,2))  ! 

  nx=size(var,1)
  ny=size(var,2)

  if(present(undef))then
     do j=1,ny
        call min_val_1d(var(:,j),tmp_num(j),tmp(j),undef)
     end do
     call min_val_1d(tmp,mimny,mimv,undef)

     if(mimny==ny+1)then
        mimnx=nx+1
     else
        mimnx=tmp_num(mimny)
     end if

  else

     do j=1,ny
        call min_val_1d(var(:,j),tmp_num(j),tmp(j))
     end do
     call min_val_1d(tmp,mimny,mimv)

     mimnx=tmp_num(mimny)
  end if

end subroutine min_val_2d



!-- Ʊͤιͤ, 3  ---
subroutine min_val_3d(var, mimnx, mimny, mimnz, mimv, undef)  ! 3 ѺǾ, ֹ롼
  implicit none
  real, intent(in) :: var(:,:,:)  ! 3 Ǿõ
  integer, intent(inout) :: mimnx  ! κǾͤ˳ 1 ֹ
  integer, intent(inout) :: mimny  ! κǾͤ˳ 2 ֹ
  integer, intent(inout) :: mimnz  ! κǾͤ˳ 3 ֹ
  real, intent(inout) :: mimv  ! κǾ
  real, intent(in), optional :: undef  ! ̤
  integer :: nx  !  1 ǤĿ(size ؿǼư׻)
  integer :: ny  !  2 ǤĿ(size ؿǼư׻)
  integer :: nz  !  3 ǤĿ(size ؿǼư׻)
  integer :: j  ! 졼ź
  real :: tmp(size(var,3))  ! 
  integer :: tmp_num1(size(var,3))  ! 
  integer :: tmp_num2(size(var,3))  ! 

  nx=size(var,1)
  ny=size(var,2)
  nz=size(var,3)

  if(present(undef))then
     do j=1,nz
        call min_val_2d(var(:,:,j),tmp_num1(j),tmp_num2(j),tmp(j),undef)
     end do
     call min_val_1d(tmp,mimnz,mimv,undef)

     if(mimnz==nz+1)then
        mimnx=nx+1
        mimny=ny+1
     else
        mimnx=tmp_num1(mimnz)
        mimny=tmp_num2(mimnz)
     end if

  else

     do j=1,nz
        call min_val_2d(var(:,:,j),tmp_num1(j),tmp_num2(j),tmp(j))
     end do
     call min_val_1d(tmp,mimnz,mimv)

     mimnx=tmp_num1(mimnz)
     mimny=tmp_num2(mimnz)
  end if

end subroutine min_val_3d



end module max_min
